# This script creates a layout file from the GEO data set

# download the individual data sets from GEO
# these are of the format: "GSM4704156_SIN6175A22_gene_counts.txt.gz"
# copy paste the samples description from the web page from the GEO website,
#   and save it as format sampleid.xlsx
#   the data is of format
#   sampleid    sampledescription
#   GSM4704133	D10_Control_1
#   GSM4704134	D10_Control_2
#   GSM4704135	D10_Control_3

#place ALL files in a subfolder called "projectName" as specified in the metadata, in folder "data"

library(tidyverse)
metadata <- readxl::read_excel("./metadata/metadata.xlsx")
dir.create(paste0("./analyses/",metadata$projectName))
writepath <- paste0("./analyses/",metadata$projectName, "/")

#load the sample description
sampleids_df <- readxl::read_excel(paste0("./data/", metadata$projectName, "/sampleid.xlsx"))

#create and write the layout file
samplefiles_df <- as_tibble(list.files(paste0("./data/", metadata$projectName), pattern= ".gz"))
samplefiles_df2 <- samplefiles_df %>% separate(value, into = c("sampleid", "index"))
samplefiles_df3 <- samplefiles_df2 %>% left_join(sampleids_df, by = "sampleid")
samplefiles_df3 <- samplefiles_df3 %>% 
  separate(sampleDescription, into = c("day", "type", "rep"), remove=T) %>% 
  unite("group", c("day", "type"))

write_csv(samplefiles_df3, paste0("./data/", metadata$projectName, "/layout.csv"))

